summaryrefslogtreecommitdiffstats
path: root/src/H5Vprivate.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5Vprivate.h')
-rw-r--r--src/H5Vprivate.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/H5Vprivate.h b/src/H5Vprivate.h
index 3840075..07692b0 100644
--- a/src/H5Vprivate.h
+++ b/src/H5Vprivate.h
@@ -124,8 +124,8 @@ H5V_vector_reduce_product(unsigned n, const hsize_t *v)
{
hsize_t ret_value = 1;
- /* Use FUNC_ENTER_NOINIT here to avoid performance issues */
- FUNC_ENTER_NOINIT(H5V_vector_reduce_product);
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5V_vector_reduce_product);
if (n && !v) HGOTO_DONE(0);
while (n--) ret_value *= *v++;
@@ -156,8 +156,8 @@ H5V_vector_zerop_u(int n, const hsize_t *v)
{
htri_t ret_value=TRUE; /* Return value */
- /* Use FUNC_ENTER_NOINIT here to avoid performance issues */
- FUNC_ENTER_NOINIT(H5V_vector_zerop_u);
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5V_vector_zerop_u);
if (!v)
HGOTO_DONE(TRUE);
@@ -191,8 +191,8 @@ H5V_vector_zerop_s(int n, const hssize_t *v)
{
htri_t ret_value=TRUE; /* Return value */
- /* Use FUNC_ENTER_NOINIT here to avoid performance issues */
- FUNC_ENTER_NOINIT(H5V_vector_zerop_s);
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5V_vector_zerop_s);
if (!v)
HGOTO_DONE(TRUE);
@@ -228,8 +228,8 @@ H5V_vector_cmp_u (int n, const hsize_t *v1, const hsize_t *v2)
{
int ret_value=0; /* Return value */
- /* Use FUNC_ENTER_NOINIT here to avoid performance issues */
- FUNC_ENTER_NOINIT(H5V_vector_cmp_u);
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5V_vector_cmp_u);
if (v1 == v2) HGOTO_DONE(0);
while (n--) {
@@ -268,8 +268,8 @@ H5V_vector_cmp_s (unsigned n, const hssize_t *v1, const hssize_t *v2)
{
int ret_value=0; /* Return value */
- /* Use FUNC_ENTER_NOINIT here to avoid performance issues */
- FUNC_ENTER_NOINIT(H5V_vector_cmp_s);
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5V_vector_cmp_s);
if (v1 == v2) HGOTO_DONE(0);
while (n--) {